Crate rfsee_tf_idf

Crate rfsee_tf_idf 

Structs

Index
ProcessedRfc
RfcDetails
RfcEntry
RfcSearchResult
TfIdf

Functions

combine_scores
compute_search_scores
fetch_rfcs
get_index_path
parse_rfcs_index

Type Aliases

DocTermFreqs
Mapping from a Url to the term frequencies for the document at that url.
DocsWithTerm
Map of terms to a vector of documents that have that term
InvDocFreqs
For each term its inverse document frequency which is computed as:
ProcessedRfcs
RfcDetailsMap
RfcNumber
Term
A term in a document
TermFreqs
Term frequency, tf(t,d), is the relative frequency of term t within document d. Keys are the terms and values are the frequency of the term
TermScore
Url
The url of the source document