Structs
Functions
Type Aliases
- DocTerm
Freqs - Mapping from a Url to the term frequencies for the document at that url.
- Docs
With Term - Map of terms to a vector of documents that have that term
- InvDoc
Freqs - For each term its inverse document frequency which is computed as:
- Processed
Rfcs - RfcDetails
Map - RfcNumber
- Term
- A term in a document
- Term
Freqs - Term frequency, tf(t,d), is the relative frequency of term t within document d. Keys are the terms and values are the frequency of the term
- Term
Score - Url
- The url of the source document